(window.webpackJsonp=window.webpackJsonp||[]).push([["reset-password"],{"8cdb":function(e,t,n){"use strict";n.r(t);var s=n("2877"),r=Object(s.a)({},(function(){var e=this.$createElement;return(this._self._c||e)("h1",[this._v("404")])}),[],!1,null,null,null);t.default=r.exports}}]);
//# sourceMappingURL=reset-password.16721f30.js.map